.. python-engineio documentation master file, created by
   sphinx-quickstart on Sat Nov 24 09:42:25 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

python-engineio
===============

This project implements Python based Engine.IO client and server that can run
standalone or integrated with a variety of Python web frameworks and
applications.

.. toctree::
   :maxdepth: 2

   intro
   client
   server
   api

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
